<?php

namespace App\Console\Commands\Push;


use App\Consts\PushConst;
use App\Libs\Push\OPPOPush\OPPOPushCommon;
use App\Modules\Push\Services\PushAppService;
use Illuminate\Console\Command;

class PushTagBind extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'push:tag:bind';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '推送标签绑定';

    /**
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function handle()
    {
        # 标签
        $tag      = PushConst::TOPIC_ALL;
        $provider = 'oppo';

        # 获取所有oppo app，初始化推送
        $apps    = PushAppService::getAppsByProvider($provider);

        # 查询所有oppo用户
        $id = 0;
        while (True) {
            var_dump('last id:'.$id);

            # 获取用户列表
            $users = PushAppService::getAppUsersByProvider($provider, $id);
            if (empty($users)) {
                break;
            }

            $groupUsers = collect($users)->groupBy('app_id')->all();
            foreach($groupUsers as $appId => $userList) {
                $regIds = collect($userList)->pluck('reg_id')->all();
                $app    = collect($apps)->firstWhere('app_id', $appId);
                var_dump($appId, count($regIds));

                // 初始化
                $appKey       = getProp($app, 'app_key');
                $masterSecret = getProp($app, 'master_secret');
                $client       = new OPPOPushCommon($appKey, $masterSecret);

                // 循环绑定
                if ($regIds && $client) {
                    foreach($regIds as $regId) {
                        $client->subscribeTags($regId, $tag);
                    }
                }
            }

            # 分页id
            $len = count($users);
            $id  = $users[$len - 1]['id'];
            var_dump('next id:'.$id);
        }
    }

    /**
     * 初始化推送实例
     *
     * @param [type] $apps
     * @return void
     */
    private function initCients($apps)
    {
        if(empty($apps)) {
            return [];
        }

        $clients = [];
        foreach($apps as $app) {
            $appId           = getProp($app, 'app_id');
            $appKey          = getProp($app, 'app_key');
            $masterSecret    = getProp($app, 'master_secret');
            $clients[$appId] = new OPPOPushCommon($appKey, $masterSecret);
        }

        return $clients;
    }

}